# Nonadditivity Core Workflow

- [`input_reader.py`](input_reader.py): Contains all functions needed to parse an input file.
- [`mmpdb_helper.py`](mmpdb_helper.py): Handles the mmpdblib functionality used by this package.
- [`nonadditivity_core.py`](nonadditivity_core.py): Contains the core algorithms for identifying the nonadditivity circles and calculating both the nonadditivity and the thoeretical quantiles for the statistical measurement uncertainty analysis.
- [`output_writer.py`](output_writer.py): All functions needed to write any output files.
- [`canonicalize_output.py`](canonicalize_output.py): All functions needed to canonicalize the output.
